import java.util.Date;
import java.util.List;

import com.perforce.p4java.client.IClient;
import com.perforce.p4java.core.ChangelistStatus;
import com.perforce.p4java.core.IChangelist;
import com.perforce.p4java.core.IChangelistSummary;
import com.perforce.p4java.core.file.FileSpecBuilder;
import com.perforce.p4java.core.file.FileSpecOpStatus;
import com.perforce.p4java.core.file.IFileSpec;
import com.perforce.p4java.exception.P4JavaException;
import com.perforce.p4java.exception.RequestException;
import com.perforce.p4java.impl.generic.core.Changelist;
import com.perforce.p4java.impl.mapbased.server.Server;
import com.perforce.p4java.server.IOptionsServer;
import com.perforce.p4java.server.ServerFactory;
import com.perforce.p4java.option.server.GetChangelistsOptions;

public class SimpleTestApp {

	public static void main(String[] args) {
		try {		
			IOptionsServer server = ServerFactory.getOptionsServer("p4java://localhost:1777", null);
			
			server.setUserName("matt");
			server.connect();
			IClient client = server.getClient("mac-matt");

			server.setCurrentClient(client);

            String path = "//depot/...@2014/03/01,@now";
			List<IFileSpec> files = FileSpecBuilder.makeFileSpecList(path);
			GetChangelistsOptions opts = new GetChangelistsOptions();
			List<IChangelistSummary> changeSummaries = server.getChangelists(files, new GetChangelistsOptions());

			for( IChangelistSummary cl : changeSummaries )
			{
				System.out.println(formatChangelist(cl));
			}

		} catch (RequestException rexc) {
			System.err.println(rexc.getDisplayString());
			rexc.printStackTrace();
		} catch (Exception exc) {
			System.err.println(exc.getLocalizedMessage());
			exc.printStackTrace();
		}
	}	
	
	protected static String formatChangelist(IChangelistSummary changelist) 
	{
		return changelist.getId() + " " + changelist.getDate()
						+ " " + changelist.getClientId()
						+ " " + changelist.getDescription();
	}
}